"""Add payment methods to database

Revision ID: eee7d931e50b
Revises: cb86df28b227
Create Date: 2025-05-20 16:45:36.161503

"""

# revision identifiers, used by Alembic.
revision = 'eee7d931e50b'
down_revision = 'cb86df28b227'

from alembic import op
import sqlalchemy as sa


def upgrade():
    op.execute("""
    CREATE TABLE payment_method (
        id serial PRIMARY KEY,
        created timestamp without time zone NOT NULL,
        user_id integer NOT NULL REFERENCES "user"(id) ON DELETE CASCADE,

        -- Expiration, if applicable to this payment method type
        expires timestamp without time zone,

        -- User-friendly name (e.g. "Visa ending in 1234")
        name text NOT NULL,

        -- Opaque processor-specific ID
        processor_id text UNIQUE NOT NULL
    );

    ALTER TABLE "user"
    ADD COLUMN default_payment_method_id integer REFERENCES payment_method(id) ON DELETE SET NULL;
    """)


def downgrade():
    op.execute("""
    ALTER TABLE "user"
    DROP COLUMN default_payment_method_id;

    DROP TABLE payment_method;
    """)
